import { AwsSdkSigV4AuthInputConfig, AwsSdkSigV4AuthResolvedConfig, AwsSdkSigV4PreviouslyResolved } from "@aws-sdk/core";
import { HandlerExecutionContext, HttpAuthScheme, HttpAuthSchemeParameters, HttpAuthSchemeParametersProvider, HttpAuthSchemeProvider } from "@smithy/types";
import { CodeCommitClientResolvedConfig } from "../CodeCommitClient";
/**
 * @internal
 */
export interface CodeCommitHttpAuthSchemeParameters extends HttpAuthSchemeParameters {
    region?: string;
}
/**
 * @internal
 */
export interface CodeCommitHttpAuthSchemeParametersProvider extends HttpAuthSchemeParametersProvider<CodeCommitClientResolvedConfig, HandlerExecutionContext, CodeCommitHttpAuthSchemeParameters, object> {
}
/**
 * @internal
 */
export declare const defaultCodeCommitHttpAuthSchemeParametersProvider: (config: CodeCommitClientResolvedConfig, context: HandlerExecutionContext, input: object) => Promise<CodeCommitHttpAuthSchemeParameters>;
/**
 * @internal
 */
export interface CodeCommitHttpAuthSchemeProvider extends HttpAuthSchemeProvider<CodeCommitHttpAuthSchemeParameters> {
}
/**
 * @internal
 */
export declare const defaultCodeCommitHttpAuthSchemeProvider: CodeCommitHttpAuthSchemeProvider;
/**
 * @internal
 */
export interface HttpAuthSchemeInputConfig extends AwsSdkSigV4AuthInputConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    httpAuthSchemes?: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    httpAuthSchemeProvider?: CodeCommitHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export interface HttpAuthSchemeResolvedConfig extends AwsSdkSigV4AuthResolvedConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    readonly httpAuthSchemes: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    readonly httpAuthSchemeProvider: CodeCommitHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export declare const resolveHttpAuthSchemeConfig: <T>(config: T & HttpAuthSchemeInputConfig & AwsSdkSigV4PreviouslyResolved) => T & HttpAuthSchemeResolvedConfig;
