import { AwsSdkSigV4AuthInputConfig, AwsSdkSigV4AuthResolvedConfig, AwsSdkSigV4PreviouslyResolved } from "@aws-sdk/core";
import { HandlerExecutionContext, HttpAuthScheme, HttpAuthSchemeParameters, HttpAuthSchemeParametersProvider, HttpAuthSchemeProvider } from "@smithy/types";
import { ECRClientResolvedConfig } from "../ECRClient";
/**
 * @internal
 */
export interface ECRHttpAuthSchemeParameters extends HttpAuthSchemeParameters {
    region?: string;
}
/**
 * @internal
 */
export interface ECRHttpAuthSchemeParametersProvider extends HttpAuthSchemeParametersProvider<ECRClientResolvedConfig, HandlerExecutionContext, ECRHttpAuthSchemeParameters, object> {
}
/**
 * @internal
 */
export declare const defaultECRHttpAuthSchemeParametersProvider: (config: ECRClientResolvedConfig, context: HandlerExecutionContext, input: object) => Promise<ECRHttpAuthSchemeParameters>;
/**
 * @internal
 */
export interface ECRHttpAuthSchemeProvider extends HttpAuthSchemeProvider<ECRHttpAuthSchemeParameters> {
}
/**
 * @internal
 */
export declare const defaultECRHttpAuthSchemeProvider: ECRHttpAuthSchemeProvider;
/**
 * @internal
 */
export interface HttpAuthSchemeInputConfig extends AwsSdkSigV4AuthInputConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    httpAuthSchemes?: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    httpAuthSchemeProvider?: ECRHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export interface HttpAuthSchemeResolvedConfig extends AwsSdkSigV4AuthResolvedConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    readonly httpAuthSchemes: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    readonly httpAuthSchemeProvider: ECRHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export declare const resolveHttpAuthSchemeConfig: <T>(config: T & HttpAuthSchemeInputConfig & AwsSdkSigV4PreviouslyResolved) => T & HttpAuthSchemeResolvedConfig;
