"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.tryDownloadDb = tryDownloadDb;
const fs_extra_1 = __importDefault(require("fs-extra"));
const node_fetch_1 = __importDefault(require("node-fetch"));
const rest_1 = require("@octokit/rest");
const got_1 = __importDefault(require("got"));
const stream_1 = require("stream");
const util_1 = require("util");
const osv_offline_db_1 = require("@renovatebot/osv-offline-db");
const path_1 = __importDefault(require("path"));
const luxon_1 = require("luxon");
const adm_zip_1 = __importDefault(require("adm-zip"));
const types_1 = require("./types");
const pipeline = (0, util_1.promisify)(stream_1.Stream.pipeline);
const baseParameters = {
    owner: 'renovatebot',
    repo: 'osv-offline',
};
async function tryDownloadDb(githubToken) {
    await fs_extra_1.default.ensureDir(osv_offline_db_1.OsvOfflineDb.rootDirectory);
    if (process.env['OSV_OFFLINE_DISABLE_DOWNLOAD']?.toLowerCase() === 'true') {
        return (0, types_1.success)();
    }
    // if local database exists and is less than a day old, don't do any network requests
    let stats;
    try {
        stats = await fs_extra_1.default.stat(path_1.default.join(osv_offline_db_1.OsvOfflineDb.rootDirectory, `osv-offline.zip`));
    }
    catch (err) {
        // ignored
    }
    if (stats !== undefined &&
        luxon_1.DateTime.utc().diff(luxon_1.DateTime.fromJSDate(stats.mtime)).as('days') < 1) {
        return (0, types_1.success)();
    }
    const octokitOptions = {
        auth: githubToken ?? process.env['GITHUB_COM_TOKEN'],
        request: { fetch: node_fetch_1.default },
    };
    let latestRelease = null;
    try {
        latestRelease = (await new rest_1.Octokit(octokitOptions).repos.listReleases({
            ...baseParameters,
        })).data[0];
    }
    catch (err) {
        return (0, types_1.failure)(err);
    }
    const asset = latestRelease?.assets.find((asset) => asset.name === 'osv-offline.zip');
    // if local database is the same size as remote database, don't download again
    if (asset?.size === stats?.size) {
        return (0, types_1.success)();
    }
    if (asset !== undefined) {
        // only download databases if local databases are missing or remote is newer
        try {
            const stream = got_1.default.stream(asset.browser_download_url);
            const zipPath = path_1.default.join(osv_offline_db_1.OsvOfflineDb.rootDirectory, asset.name);
            const writeStream = fs_extra_1.default.createWriteStream(zipPath);
            await pipeline(stream, writeStream);
            const zip = new adm_zip_1.default(zipPath);
            zip.extractAllTo(osv_offline_db_1.OsvOfflineDb.rootDirectory);
        }
        catch (err) {
            return (0, types_1.failure)(err);
        }
    }
    return (0, types_1.success)();
}
